import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " Inches" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.max_height_male)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.max_height_male))
  	.on("mouseover", d => console.log(d.data.max_height_male));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each Name as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.max_height_male));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.max_height_male));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/Rajayaswanthvarma/9245051e3e82ed24ced664e287279f03/raw/d2849f509f89f6559eb8bf07b0f6a4e7dd485d66/ICE6_dogbreeds.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.max_height_male-data1.max_height_male);
    if (csvData) {
      render(csvData.slice(0, 8));
    }
});